<?php
/*-----------------------------------------------------------------------------------*/
/*  Print custom CSS set up in the theme options
/*-----------------------------------------------------------------------------------*/
class Wolf_Custom_Options_Styles {

	function hex_to_rgb($hex) {
		$hex = str_replace("#", "", $hex);

		if (strlen($hex) == 3) {
		$r = hexdec(substr($hex,0,1).substr($hex,0,1));
		$g = hexdec(substr($hex,1,1).substr($hex,1,1));
		$b = hexdec(substr($hex,2,1).substr($hex,2,1));
		} else {
		$r = hexdec(substr($hex,0,2));
		$g = hexdec(substr($hex,2,2));
		$b = hexdec(substr($hex,4,2));
		}
		$rgb = array($r, $g, $b);
		return implode(",", $rgb); // returns the rgb values separated by commas
		//return $rgb; // returns an array with the rgb values
	}

	// --------------------------------------------------------------------------

	function brightness($hex, $percent) {

		$steps = (ceil(($percent*200) / 100))*2;

		// Steps should be between -255 and 255. Negative = darker, positive = lighter
		$steps = max(-255, min(255, $steps));

		// Format the hex color string
		$hex = str_replace('#', '', $hex);
		if (strlen($hex) == 3) {
		$hex = str_repeat(substr($hex,0,1), 2).str_repeat(substr($hex,1,1), 2).str_repeat(substr($hex,2,1), 2);
		}

		// Get decimal values
		$r = hexdec(substr($hex,0,2));
		$g = hexdec(substr($hex,2,2));
		$b = hexdec(substr($hex,4,2));

		// Adjust number of steps and keep it inside 0 to 255
		$r = max(0,min(255,$r + $steps));
		$g = max(0,min(255,$g + $steps));  
		$b = max(0,min(255,$b + $steps));

		$r_hex = str_pad(dechex($r), 2, '0', STR_PAD_LEFT);
		$g_hex = str_pad(dechex($g), 2, '0', STR_PAD_LEFT);
		$b_hex = str_pad(dechex($b), 2, '0', STR_PAD_LEFT);

		return '#'.$r_hex.$g_hex.$b_hex;
	}

	// --------------------------------------------------------------------------

	/**
	 * Return background inline CSS
	 */
	function get_bg_options( $id = null, $selector = null ) {

		$css = '';

		$img = '';
		$color = wolf_get_theme_option($id.'_color');
		$repeat = wolf_get_theme_option($id.'_repeat');
		$position = wolf_get_theme_option($id.'_position');
		$attachment = wolf_get_theme_option($id.'_attachment');
		$size = wolf_get_theme_option($id.'_size');
			
		if ( wolf_get_theme_option($id.'_img') )
			$img = 'url("'. wolf_get_theme_option($id.'_img') .'")';

		if ( $color || $img ) { 

			$css .= "$selector{background:none;}";
			
			if ( !$img ) {
				$css .= "$selector {background-color:$color;}";
			}
				
							
			if ( $img )  {

				$css .= "$selector {background : $color $img $position $repeat $attachment}";
				
				if ($size == 'cover') {

					$css .= "$selector {-webkit-background-size: cover; -o-background-size: cover; background-size: cover;}";
				}
					
			}
		} 
		
		return $css;
	}

	// --------------------------------------------------------------------------

	/**
	 * Return theme options inline CSS
	 */
	function css_options() {
		
		$css = '';
		

		/*-----------------------------------------------------------------------------------*/
		/*  Backgrounds
		/*-----------------------------------------------------------------------------------*/

		$body = 'body, body.light, body.dark';

		$backgrounds = array(
			'body_bg' => $body,
		);


		foreach ( $backgrounds as $k => $v ) {
			
			$css .= $this->get_bg_options( $k, $v );
		}


		/*-----------------------------------------------------------------------------------*/
		/*  Overlay Color
		/*-----------------------------------------------------------------------------------*/

		$overlay = wolf_get_theme_option( 'overlay_color' );

		if ( $overlay ) {

			$css .= "#overlay{background:$overlay}";

		}

		/*-----------------------------------------------------------------------------------*/
		/*  Heading Font
		/*-----------------------------------------------------------------------------------*/

		$heading_font = wolf_get_theme_option( 'heading_google_font_name' );

		if ( $heading_font ){
			$css .= "h1, h2, h3, h4, h5, h6{font-family:'$heading_font'}";
		}

		$heading_font_weight = wolf_get_theme_option( 'heading_google_font_weight' );

		if ( $heading_font_weight ){
			$css .= "h1, h2, h3, h4, h5, h6{font-weight:$heading_font_weight}";
		}

		$heading_font_transform = wolf_get_theme_option( 'heading_google_font_transform' );

		if ( $heading_font_transform == 'uppercase' ){
			$css .= "h1, h2, h3, h4, h5, h6{text-transform:uppercase}";
		}

		/*-----------------------------------------------------------------------------------*/
		/*  Menu Font
		/*-----------------------------------------------------------------------------------*/

		$menu_font = wolf_get_theme_option( 'menu_google_font_name' );

		if( $menu_font ){
			$css .= ".nav-menu li a{ font-family:'$menu_font'}";
		}

		$menu_font_weight = wolf_get_theme_option( 'menu_google_font_weight' );

		if( $menu_font_weight ){
			$css .= ".nav-menu li a{font-weight:$menu_font_weight}";
		}

		$menu_font_transform = wolf_get_theme_option( 'menu_google_font_transform' );

		if ( $menu_font_transform == 'uppercase' ){
			$css .= ".main-navigation .nav-menu{text-transform:uppercase}";
		}

		/*-----------------------------------------------------------------------------------*/
		/*  Body Font
		/*-----------------------------------------------------------------------------------*/

		$body_font = wolf_get_theme_option( 'body_google_font_name' );

		if( $body_font ){
			$css .= "body{font-family:'$body_font'}";
		}

		/*-----------------------------------------------------------------------------------*/
		/*  Custom CSS
		/*-----------------------------------------------------------------------------------*/

		if ( wolf_get_theme_option( 'custom_css' ) ) { 
			$css .= stripslashes( wolf_get_theme_option( 'custom_css' ) );
		} 


		return $css;
	}

	// --------------------------------------------------------------------------

	/**
	* Render Custom Background Style
	**/
	function render_background( $meta_id = '_post_bg', $selector = 'body' ) {
		
		global $post, $wp_query;
		$css = '';
		
		if ( ! is_404() && ! is_tax() && ! is_search() && $post ) {
			
			$post_id = $post->ID;
			$is_post_index = false;
			$is_page_for_posts = get_option('page_for_posts');

			if ( $wp_query && isset ( $wp_query->queried_object_id ) ) {
				if ( $is_page_for_posts && $is_page_for_posts ==  $wp_query->queried_object_id ) {
					$post_id =  $wp_query->queried_object_id;
					$is_post_index = true;
				}
			}

			if ( is_single() || is_page() || $is_post_index || is_archive() ) {

				if ( is_archive() && $is_page_for_posts )
					$post_id = get_option('page_for_posts');
				
				$url = null;
				$img = get_post_meta( $post_id, $meta_id . '_img', true );
				$color = get_post_meta( $post_id, $meta_id . '_color', true );
				$repeat = get_post_meta( $post_id, $meta_id . '_repeat', true );
				$position = get_post_meta( $post_id, $meta_id . '_position', true );
				$attachment = get_post_meta( $post_id, $meta_id . '_attachment', true );
				$size = get_post_meta( $post_id, $meta_id . '_size', true );
				$parallax = get_post_meta( $post_id, $meta_id . '_parallax', true );
				
				if ( $img )
					$url = 'url("'. $img .'")';

				if ( $color || $img ) { 
					
					if ( $parallax ) {

						$css .= "$selector {background : $color $url $repeat fixed}";
						$css .= "$selector {background-position : 50% 0}";

					} else {
						$css .= "$selector {background : $color $url $position $repeat $attachment}";
					}
					
					if ($size == 'cover') {

							$css .= "$selector {
								-webkit-background-size: 100%; 
								-o-background-size: 100%; 
								-moz-background-size: 100%; 
								background-size: 100%;
								-webkit-background-size: cover; 
								-o-background-size: cover; 
								background-size: cover;
							}";
						}

					if ($size == 'resize') {

						$css .= "$selector {
							-webkit-background-size: 100%; 
							-o-background-size: 100%; 
							-moz-background-size: 100%; 
							background-size: 100%;
						}";
					}
							
				} 

			}
			return $css;
		} 
	} // end render background & custom CSS

	// --------------------------------------------------------------------------

	function render_custom_css() {
		global $post, $wp_query;
		$css = '';
		
		if ( ! is_404() && ! is_tax() && ! is_search() && $post ) {
			
			$post_id = $post->ID;
			$is_post_index = false;
			$is_page_for_posts = get_option('page_for_posts');

			if ( $wp_query && isset ( $wp_query->queried_object_id ) ) {
				if ( $is_page_for_posts && $is_page_for_posts ==  $wp_query->queried_object_id ) {
					$post_id =  $wp_query->queried_object_id;
					$is_post_index = true;
				}
			}

			if ( is_single() || is_page() || $is_post_index || is_archive() ) {

				if ( is_archive() && $is_page_for_posts )
					$post_id = get_option('page_for_posts');
				
				$custom_css = get_post_meta( $post_id, '_custom_css', true );
				
				if ( $custom_css ) {
					$css .= $custom_css ;
				}
				

			}
			return $css;
		} 
	}

	// --------------------------------------------------------------------------

	function render_background_prallax( $meta_id = '_post_bg' ) {

		global $post, $wp_query;
		$js = '';
		
		if ( ! is_404() && ! is_tax() && ! is_search() && $post ) {
			
			$post_id = $post->ID;
			$is_post_index = false;
			$is_page_for_posts = get_option('page_for_posts');

			if ( $wp_query && isset ( $wp_query->queried_object_id ) ) {
				if ( $is_page_for_posts && $is_page_for_posts ==  $wp_query->queried_object_id ) {
					$post_id =  $wp_query->queried_object_id;
					$is_post_index = true;
				}
			}

			if ( is_single() || is_page() || $is_post_index || is_archive() ) {

				if ( is_archive() && $is_page_for_posts )
					$post_id = get_option('page_for_posts');
				
				$parallax = get_post_meta( $post_id, $meta_id . '_parallax', true );
				
				if ( $parallax ) {
					$selector = '#masthead';
					$js .= '$( "' . $selector . '" ).addClass( "section-parallax" );';
				}

			}
			
			if ( $js )
				return '<script type="text/javascript">jQuery(document).ready(function($) {' . $js . '});</script>'."\n";
		} 
	}

} // end class

global $wolf_custom_options_css;
$wolf_custom_options_css = new Wolf_Custom_Options_Styles;

/**
 * Return the custom CSS
 */
function wolf_output_css() {
	global $wolf_custom_options_css;
	$output = '';
	$output .= "\n" . '/* Single Post Custom Styles CSS */' . "\n";
	
	if ( WOLF_DEBUG ) {
		$output .= $wolf_custom_options_css->render_background( '_body_bg', 'body' );
		$output .= $wolf_custom_options_css->render_background( '_header_bg', '#masthead' );
		$output .= $wolf_custom_options_css->render_custom_css();
		$output .= "\n\n";
	} else {
		$output .= wolf_compact_css( $wolf_custom_options_css->render_background( '_body_bg', 'body' ) );
		$output .= wolf_compact_css( $wolf_custom_options_css->render_background( '_header_bg', '#masthead' ) );
		$output .= wolf_compact_css( $wolf_custom_options_css->render_custom_css() );
	}
	

	$output .= "\n" . '/* Custom Options CSS */' . "\n";

	if ( WOLF_DEBUG ) {
		$output .= $wolf_custom_options_css->css_options();
		$output .= "\n\n";
	} else {
		$output .= preg_replace( '/\s+/', ' ',$wolf_custom_options_css->css_options() );	
	}
	

	return '<style type="text/css">'.$output.'</style>'."\n";
}


/**
 * Parallax
 */
function wolf_output_parallax_js() {
	
	global $wolf_custom_options_css;
	$output = '';
	$output .= "\n" . '<!-- Single Post Header Background Parallax -->' . "\n";
	$output .= $wolf_custom_options_css->render_background_prallax( '_header_bg' );
	$output .= "\n\n";

	return $output;
}

/**
 * Output the custom CSS
 */
function wolf_render_custom_css() {
    	echo wolf_output_css();
    	echo wolf_output_parallax_js();
}
add_action( 'wp_head', 'wolf_render_custom_css' );
?>
